@@ -1,24 +1,32 @@
 from .version import __version__
-from .config import *
+from .config import (
+    TACOZ_OK,
+    TACOZ_ERR_IO,
+    TACOZ_ERR_LIBZIP,
+    TACOZ_ERR_INVALID_HEADER,
+    TACOZ_ERR_PARAM,
+    TACOZ_ERR_NOT_FOUND,
+    TACOZ_ERR_EXISTS,
+    TACOZ_ERR_TOO_LARGE,
+    TACO_HEADER_MAX_ENTRIES,
+)
 from .exceptions import TacozipError
 from .loader import self_check
-
-# Import simplified API from bindings
 from .bindings import (
-    create, update_header, append_files, replace_file, get_library_version, read_header, trim_from
+    create,
+    update_header,
+    read_header,
+    get_library_version,
 )
 
-# Package metadata
 __author__ = "Cesar Aybar"
 __author_email__ = "cesar.aybar@uv.es"
-__description__ = "TACO ZIP: ZIP64 archive with TACO Header supporting up to 7 metadata entries"
+__description__ = "Regular ZIP (STORE-only) writer with libzip backend and TACO Header at byte 0."
 __url__ = "https://github.com/tacofoundation/tacozip"
 __license__ = "MIT"
 __tacozip_version__ = get_library_version()
 
-# Export public API
 __all__ = [
-    # Version
     "__version__",
     "__tacozip_version__",
     "__author__",
@@ -26,29 +34,19 @@ __all__ = [
     "__description__",
     "__url__",
     "__license__",
-    
-    # loader
     "self_check",
-
-    # Constants
     "TACOZ_OK",
     "TACOZ_ERR_IO",
-    "TACOZ_ERR_LIBZIP", 
+    "TACOZ_ERR_LIBZIP",
     "TACOZ_ERR_INVALID_HEADER",
     "TACOZ_ERR_PARAM",
     "TACOZ_ERR_NOT_FOUND",
     "TACOZ_ERR_EXISTS",
+    "TACOZ_ERR_TOO_LARGE",
     "TACO_HEADER_MAX_ENTRIES",
-    
-    # Exceptions
     "TacozipError",
-    
-    # Core API
     "create",
-    "update_header", 
-    "append_files",
-    "replace_file",
-    "trim_from",
+    "update_header",
     "read_header",
-    "get_library_version"
+    "get_library_version",
 ]
\ No newline at end of file
